==========
csvmimesis
==========


Generate dummy tables using the mimesis data provider


Description
===========

This is a small library to generate dummy tables based on the providers of the mimesis library


Similar projects:
* csvfaker: https://github.com/pereorga/csvfaker

Note
====

This project has been set up using PyScaffold 3.0.3. For details and usage
information on PyScaffold see http://pyscaffold.org/.

